<?php

/**
 * Plugin Name: BWL Advanced FAQ Manager
 * Plugin URI: https://1.envato.market/baf-wp
 * Description: A WordPress plugin designed for managing unlimited number of FAQs and display on your website.
 * Author: Mahbub Alam Khan
 * Version: 2.1.5
 * Author URI: https://codecanyon.net/user/xenioushk
 * WP Requires at least: 6.0+
 * Text Domain: bwl-adv-faq
 * Domain Path: /lang/
 *
 * @package BwlFaqManager
 * @author Mahbub Alam Khan
 * @license GPL-2.0+
 * @link https://codecanyon.net/user/xenioushk
 * @copyright 2025 BlueWindLab
 */

namespace BwlFaqManager;

// security check.
defined( 'ABSPATH' ) || die( 'Unauthorized access' );

// Once we get here, We have passed all validation checks so we can safely include our plugin

if ( file_exists( __DIR__ . '/vendor/autoload.php' ) ) {
	require_once __DIR__ . '/vendor/autoload.php';
}

use BwlFaqManager\Base\Activate;
use BwlFaqManager\Base\Deactivate;

if ( ! class_exists( 'BWL_Advanced_Faq_Manager' ) ) {

    /**
     * Function to handle the activation of the plugin.
     *
     * @return void
     */
    function activate_plugin() { // phpcs:ignore
        global $wpdb;
        $activate = new Activate( $wpdb );
        $activate->activate();
        $activate->create_db_tables();
    }

    /**
     * Function to handle the deactivation of the plugin.
     *
     * @return void
     */
    function deactivate_plugin() { // phpcs:ignore
        Deactivate::deactivate();
    }

    register_activation_hook( __FILE__, __NAMESPACE__ . '\\activate_plugin' );
    register_deactivation_hook( __FILE__, __NAMESPACE__ . '\\deactivate_plugin' );

    /**
     * Function to handle the initialization of the Advanced FAQ Manager
     *
     * @return void
     */
    function init_baf_manager() {

		if ( class_exists( 'BwlFaqManager\\Init' ) ) {
            Init::register_services();
        }
    }

    add_action( 'init', __NAMESPACE__ . '\\init_baf_manager' );

    include_once __DIR__ . '/includes/Widgets/index.php';

}
