<?php
namespace BwlFaqManager\Base;

use Xenioushk\BwlPluginApi\Api\AjaxHandlers\AjaxHandlersApi;
use BwlFaqManager\Callbacks\ShortcodeEditor\PluginScEditorCb;
use BwlFaqManager\Callbacks\AdminAjaxHandlers\PluginInstallationCb;
use BwlFaqManager\Callbacks\AdminAjaxHandlers\TaxonomySortDataCb;
use BwlFaqManager\Callbacks\AdminAjaxHandlers\TaxonomySortSaveCb;
use BwlFaqManager\Callbacks\AdminAjaxHandlers\PurchaseVerifyCb;
/**
 * Class for admin ajax handlers.
 *
 * @package BwlFaqManager
 */
class AdminAjaxHandlers {
	/**
	 * Ajax handlers api.
	 *
	 * @var object $ajax_handlers_api
	 */
	public $ajax_handlers_api;


	/**
	 * Plugin shortcode editor callback
	 *
	 * @var object $plugin_shortcode_editor_cb
	 */
	public $plugin_shortcode_editor_cb;

	/**
	 * Plugin installation callback
	 *
	 * @var object $plugin_installation_cb
	 */
	public $plugin_installation_cb;

	/**
	 * Plugin purchase verify callback
	 *
	 * @var object $plugin_purchase_verify_cb
	 */
	public $plugin_purchase_verify_cb;

	/**
	 * Taxonomy sort data callback
	 *
	 * @var object $taxonomy_sort_data_cb
	 */
	public $taxonomy_sort_data_cb;

	/**
	 * Taxonomy sort data callback
	 *
	 * @var object $taxonomy_sort_save_cb
	 */
	public $taxonomy_sort_save_cb;

	/**
	 * Register admin ajax handlers.
	 */
	public function register() {

		$this->ajax_handlers_api          = new AjaxHandlersApi();
		$this->plugin_shortcode_editor_cb = new PluginScEditorCb();
		$this->plugin_installation_cb     = new PluginInstallationCb();
		$this->taxonomy_sort_data_cb      = new TaxonomySortDataCb();
		$this->taxonomy_sort_save_cb      = new TaxonomySortSaveCb();
		$this->plugin_purchase_verify_cb  = new PurchaseVerifyCb();

		// Do not change the tag.
		// If do so, you need to change in js file too.
		$adminAjaxRequests = [
			[
				'tag'      => 'baf_sc_content',
				'callback' => [ $this->plugin_shortcode_editor_cb, 'display_editor' ],
			],
			[
				'tag'      => 'baf_installation_counter',
				'callback' => [ $this->plugin_installation_cb, 'save' ],
			],
			[
				'tag'      => 'baf_get_sorting_data',
				'callback' => [ $this->taxonomy_sort_data_cb, 'get_data' ],
			],
			[
				'tag'      => 'bwl_advanced_faq_apply_sort',
				'callback' => [ $this->taxonomy_sort_save_cb, 'save' ],
			],
			[
				'tag'      => 'bafVerifyPurchaseData',
				'callback' => [ $this->plugin_purchase_verify_cb, 'verify' ],
			],
			[
				'tag'      => 'bafRemoveLicenseData',
				'callback' => [ $this->plugin_purchase_verify_cb, 'remove' ],
			],

		];

		$this->ajax_handlers_api->add_ajax_handlers( $adminAjaxRequests )->register();
	}
}
