<?php
namespace BwlFaqManager\Base;

/**
 * Class for registering the plugin admin scripts and styles.
 *
 * @package BwlFaqManager
 */
class AdminEnqueue {

	/**
	 * Admin script slug.
	 *
	 * @var string $admin_script_slug
	 */
	private $admin_script_slug;

	/**
	 * Constructor.
	 */
	public function __construct() {
		// Frontend script slug.
		// This is required to hook the loclization texts.
		$this->admin_script_slug = 'baf-admin';
	}

	/**
	 * Register the plugin scripts and styles loading actions.
	 */
	public function register() {
		// for admin.
		add_action( 'admin_enqueue_scripts', [ $this, 'get_the_scripts' ] );
	}
	/**
     * Load the plugin styles and scripts.
     */
	public function get_the_scripts() {

		// Load admin styles & scripts.
		wp_enqueue_style(
            $this->admin_script_slug,
            BAF_STYLES_ASSETS_DIR . 'admin.css',
            [ 'wp-color-picker' ],
            BAF_PLUGIN_VERSION
		);

		if ( is_rtl() ) {
			wp_enqueue_style(
				$this->admin_script_slug . '-rtl',
				BAF_STYLES_ASSETS_DIR . 'admin_rtl.css',
				[],
				BAF_PLUGIN_VERSION
			);
		}

            // TinyMCE Editor Style.
            wp_register_style(
                'bwl-advanced-faq-editor-style',
                BAF_LIBS_DIR . 'tinymce/styles/shortcode-editor.css',
                [],
                BAF_PLUGIN_VERSION
            );
            wp_register_style(
                'bwl-advanced-faq-multiple-select',
                BAF_LIBS_DIR . 'multiple-select/styles/multiple-select.css',
                [],
                BAF_PLUGIN_VERSION
            );
            wp_register_script(
                'bwl-advanced-faq-multiple-select',
                BAF_LIBS_DIR . 'multiple-select/scripts/jquery.multiple.select.js',
                [ 'jquery', 'jquery-ui-core', 'jquery-ui-draggable', 'jquery-ui-droppable' ],
                BAF_PLUGIN_VERSION,
                true
            );

            // Chart JS.
            wp_register_script(
                'baf-chart-js',
                BAF_LIBS_DIR . 'chart-js/scripts/chart.js',
                [ 'jquery' ],
                BAF_PLUGIN_VERSION,
                true
            );

            // Enqueue FAQ Admin Script & Style.
            wp_enqueue_style( 'bwl-advanced-faq-editor-style' ); // TinyMCE Editor Overlay.
            wp_enqueue_style( 'bwl-advanced-faq-multiple-select' ); // Enqueue Multiselect Style.
            wp_enqueue_script( 'bwl-advanced-faq-multiple-select' ); // Enqueue Multiselect Script.

						// Enqueue the scripts.
						$this->conditional_enqueue_scripts();

            wp_enqueue_script(
                $this->admin_script_slug,
                BAF_SCRIPTS_ASSETS_DIR . 'admin.js',
                [
					'jquery',
					'wp-color-picker',
					'jquery-ui-core',
					'jquery-ui-draggable',
					'jquery-ui-droppable',
					'jquery-ui-sortable',
				],
                BAF_PLUGIN_VERSION,
                true
            );
		// Load frontend variables used by the JS files.
		$this->get_the_localization_texts();
	}

	/**
	 * Load the localization texts.
	 */
	private function get_the_localization_texts() {

		// Localize scripts.
		// Frontend.
		// Access data: BptmAdminData.version
		wp_localize_script(
            $this->admin_script_slug,
            'BafAdminData',
            [
				'ajaxurl'              => esc_url( admin_url( 'admin-ajax.php' ) ),
				'baf_text_loading'     => esc_attr__( 'Loading .....', 'bwl-adv-faq' ),
				'baf_pvc_required_msg' => esc_attr__( 'Purchase code is required!', 'bwl-adv-faq' ),
				'baf_pvc_success_msg'  => esc_attr__( 'Purchase code verified. Reloading window in 3 seconds.', 'bwl-adv-faq' ),
				'baf_pvc_failed_msg'   => esc_attr__( 'Unable to verify purchase code. Please try again or contact support team.', 'bwl-adv-faq' ),
				'baf_pvc_remove_msg'   => esc_attr__( 'Are you sure to remove the license info?', 'bwl-adv-faq' ),
				'baf_pvc_removed_msg'  => esc_attr__( 'Purchase code removed. Reloading window in 3 seconds.', 'bwl-adv-faq' ),
				'product_id'           => BAF_PRODUCT_ID,
				'installation'         => get_option( BAF_PRODUCT_INSTALLATION_TAG ),
				'baf_dir'              => BAF_URL, // for tinymce editor.
				'baf_text_saving'      => esc_attr__( 'Saving', 'bwl-adv-faq' ), // sort faq.
				'baf_text_saved'       => esc_attr__( 'Saved', 'bwl-adv-faq' ), // sort faq.
			]
		);
	}

	/**
	 * Conditional enqueue scripts.
	 */
	private function conditional_enqueue_scripts() {

		if ( function_exists( 'get_current_screen' ) ) {
			$screen = get_current_screen();
			if ( $screen
			&& $screen->post_type === BAF_POST_TYPE
			&& $screen->base === 'bwl_advanced_faq_page_bwl-advanced-faq-analytics'
			) {
					wp_enqueue_script( 'baf-chart-js' );
			}
		}
	}
}
