<?php
namespace BwlFaqManager\Controllers\Cpt;

use Xenioushk\BwlPluginApi\Api\Cpt\CptApi;
use BwlFaqManager\Helpers\PluginConstants;

/**
 * Class for Advanced FAQ custom post type.
 *
 * @package BwlFaqManager
 * @since: 1.0.0
 * @author: Mahbub Alam Khan
 */
class PluginCpt {

	/**
	 *  Instance of the CPT API.
	 *
	 * @var object $cpt_api
	 */
	public $cpt_api;

	/**
	 * CPT settings.
	 *
	 * @var array
	 */
	public $cpt_settings = [];

	/**
	 * Taxonomy settings.
	 *
	 * @var array
	 */
	public $tax_settings = [];

	/**
	 * Taxonomy labels.
	 *
	 * @var array
	 */
	public $tax_labels = [];

	/**
	 * Plugin options.
	 *
	 * @var array
	 */

	public $options = [];

	/**
	 * Register custom post type.
	 */
	public function register() {

		$this->options = PluginConstants::$plugin_options;

		$this->cpt_api = new CptApi();
		$this->set_cpt();
		$this->set_taxonomy();

		$this->cpt_api
						->add_cpt( $this->cpt_settings )
						->with_taxonomy( $this->tax_settings )
						->register();

		$this->flush_rewrite_rules();

	}

	/**
	 * Set CPT settings.
	 * return void
	 */
	private function set_cpt() {

		$labels = [
			'name'               => esc_html__( 'All', 'bwl-adv-faq' ) . ' ' . BAF_P_FAQ_TEXT,
			'singular_name'      => BAF_S_FAQ_TEXT,
			'add_new'            => esc_html__( 'Add New', 'bwl-adv-faq' ) . ' ' . BAF_S_FAQ_TEXT,
			'add_new_item'       => esc_html__( 'Add New', 'bwl-adv-faq' ) . ' ' . BAF_S_FAQ_TEXT,
			'edit_item'          => esc_html__( 'Edit', 'bwl-adv-faq' ) . ' ' . BAF_S_FAQ_TEXT,
			'new_item'           => esc_html__( 'New', 'bwl-adv-faq' ) . ' ' . BAF_S_FAQ_TEXT,
			'all_items'          => esc_html__( 'All', 'bwl-adv-faq' ) . ' ' . BAF_P_FAQ_TEXT,
			'view_item'          => esc_html__( 'View', 'bwl-adv-faq' ) . ' ' . BAF_S_FAQ_TEXT,
			'search_items'       => esc_html__( 'Search', 'bwl-adv-faq' ) . ' ' . BAF_S_FAQ_TEXT,
			'not_found'          => esc_html__( 'Not found', 'bwl-adv-faq' ),
			'not_found_in_trash' => esc_html__( 'Not found in Trash', 'bwl-adv-faq' ),
			'parent_item_colon'  => '',
			'menu_name'          => BAF_MENU_TEXT,
		];

		$this->cpt_settings = [
			[
				'labels'             => $labels,
				'query_var'          => BAF_CPT_QUERY_VAR,
				'post_type'          => BAF_POST_TYPE,
				'menu_name'          => BAF_CPT_MENU_NAME,
				'singular_name'      => BAF_CPT_SINGULAR_NAME,
				'slug'               => BAF_CPT_SLUG,
				'show_in_rest'       => BAF_CPT_SHOW_IN_REST,
				'supports'           => $this->get_cpt_supports(),
				'menu_icon'          => BAF_LIBS_DIR . 'cpt-icon/faq_icon.png',
				'has_archive'        => false,
				'hierarchical'       => true,
				'publicly_queryable' => BAF_CPT_PUBLICLY_QUERYABLE,
				'rewrite'            => [
					'slug'       => BAF_CPT_REWRITE_SLUG,
					'with_front' => true,
				],
			],
		];
	}

	/**
	 * Set taxonomy labels.
	 *
	 * @return void
	 */
	private function set_tax_labels() {

		$this->tax_labels = [

			BAF_TAX_CAT => [
				'name'                         => BAF_S_FAQ_TEXT . ' ' . esc_html__( ' Category', 'bwl-adv-faq' ),
				'singular_name'                => esc_html__( 'Category', 'bwl-adv-faq' ),
				'edit_item'                    => esc_html__( 'Edit Category', 'bwl-adv-faq' ),
				'update_item'                  => esc_html__( 'Update category', 'bwl-adv-faq' ),
				'add_new_item'                 => esc_html__( 'Add Category', 'bwl-adv-faq' ),
				'new_item_name'                => esc_html__( 'Add New category', 'bwl-adv-faq' ),
				'all_items'                    => esc_html__( 'All categories', 'bwl-adv-faq' ),
				'search_items'                 => esc_html__( 'Search categories', 'bwl-adv-faq' ),
				'popular_items'                => esc_html__( 'Popular categories', 'bwl-adv-faq' ),
				'separate_items_with_comments' => esc_html__( 'Separate categories with commas', 'bwl-adv-faq' ),
				'add_or_remove_items'          => esc_html__( 'Add or remove category', 'bwl-adv-faq' ),
				'choose_from_most_used'        => esc_html__( 'Choose from most used categories', 'bwl-adv-faq' ),
			],

			BAF_TAX_TOPIC => [
				'name'                         => BAF_S_FAQ_TEXT . ' ' . esc_html__( 'Topics', 'bwl-adv-faq' ),
				'singular_name'                => esc_html__( 'Topics', 'bwl-adv-faq' ),
				'edit_item'                    => esc_html__( 'Edit Topics', 'bwl-adv-faq' ),
				'update_item'                  => esc_html__( 'Update Topics', 'bwl-adv-faq' ),
				'add_new_item'                 => esc_html__( 'Add Topic', 'bwl-adv-faq' ),
				'new_item_name'                => esc_html__( 'Add New Topics', 'bwl-adv-faq' ),
				'all_items'                    => esc_html__( 'All Topics', 'bwl-adv-faq' ),
				'search_items'                 => esc_html__( 'Search Topics', 'bwl-adv-faq' ),
				'popular_items'                => esc_html__( 'Popular Topics', 'bwl-adv-faq' ),
				'separate_items_with_comments' => esc_html__( 'Separate Topics with commas', 'bwl-adv-faq' ),
				'add_or_remove_items'          => esc_html__( 'Add or remove Topics', 'bwl-adv-faq' ),
				'choose_from_most_used'        => esc_html__( 'Choose from most used Topics', 'bwl-adv-faq' ),
			],
		];
	}

	/**
	 * Set taxonomy settings.
     *
	 * @return void
	 */
	private function set_taxonomy() {

		$this->set_tax_labels();

		$this->tax_settings = [
			[
				'tax_title'       => BAF_TAX_CAT_TITLE,
				'tax_slug'        => BAF_TAX_CAT,
				'show_in_rest'    => BAF_CPT_SHOW_IN_REST,
				'custom_tax_slug' => BAF_TAX_CAT_SLUG,
				'labels'          => $this->tax_labels[ BAF_TAX_CAT ],
			],
			[
				'tax_title'       => BAF_TAX_TOPIC_TITLE,
				'tax_slug'        => BAF_TAX_TOPIC,
				'show_in_rest'    => BAF_CPT_SHOW_IN_REST,
				'custom_tax_slug' => BAF_TAX_TOPIC_SLUG,
				'labels'          => $this->tax_labels[ BAF_TAX_TOPIC ],
			],
		];
	}

	/**
	 * Get CPT supports.
	 *
	 * @return array
	 */
	private function get_cpt_supports() {

		$supports = [ 'title', 'editor', 'revisions', 'author' ];

		if ( isset( PluginConstants::$plugin_options['baf_comment_status'] )
		&& (string) PluginConstants::$plugin_options['baf_comment_status'] === 'on' ) {

			$supports[] = 'comments';
		}

		return $supports;
	}

	/**
	 * Flush rewrite rules.
	 */
	private function flush_rewrite_rules() {

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}

		$slug      = BAF_CPT_REWRITE_SLUG;
		$prev_slug = get_option( 'baf_old_custom_slug' );

		if ( ! empty( $prev_slug ) ) {
			update_option( 'baf_old_custom_slug', $slug );
		}

		if ( $slug !== $prev_slug ) {
			flush_rewrite_rules();
			update_option( 'baf_old_custom_slug', $slug );
		}
	}
}
