<?php

namespace BwlFaqManager\Controllers\Notices;

use Xenioushk\BwlPluginApi\Api\Notices\NoticesApi;
use BwlFaqManager\Callbacks\Notices\NoticeCb;

/**
 * Class PluginNotices
 *
 * This class handles the registration of the plugin admin notices.
 *
 * @since: 1.1.1
 * @package BwlFaqManager
 */
class PluginNotices {

	/**
	 * Notice callback.
	 *
	 * @var notice_cb
	 */
	public $notice_cb;

	/**
	 * Notices API.
	 *
	 * @var notices_api
	 */
	public $notices_api;

	/**
	 * Register PluginNotices.
	 */
	public function register() {

		add_action( 'admin_init', [ $this, 'initialize' ] );

	}

	/**
	 * Initialize PluginNotices.
	 */
	public function initialize() {

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}
		// Initialize API.
		$this->notices_api = new NoticesApi();

		// Initialize callbacks.
		$this->notice_cb = new NoticeCb();

		$notices = [
			[
				'callback' => [ $this->notice_cb, 'get_the_notice' ],
				'notice'   => [
					'noticeClass' => 'success',
					'msg'         => '<span class="dashicons dashicons-megaphone bwl_plugins_notice_text--success"></span><strong class="bwl_plugins_notice_text--success bwl_plugins_notice_text--bold"> Good News !</strong> We have added a <a href="' . BAF_PRODUCT_YOUTUBE_PLAYLIST . '" class="bwl_activation_link">YouTube Playlists</a> for the ' . BAF_PLUGIN_TITLE . ' plugin.',
					'key'         => 'baf_youtube_playlist_status',
					'status'      => (int) get_option( 'baf_youtube_playlist_status' ),
				],
			],
			[
				'callback' => [ $this->notice_cb, 'get_the_notice' ],
				'notice'   => [
					'noticeClass' => 'success',
					'msg'         => '<span class="dashicons dashicons-megaphone bwl_plugins_notice_text--success"></span> Good News ! We have improved the analytics feature of the FAQ posts. <a href="' . get_admin_url() . 'edit.php?post_type=bwl_advanced_faq&page=bwl-advanced-faq-analytics" class="bwl_activation_link">Check Now</a>.',
					'key'         => 'baf_aps_2_0_2',
					'status'      => (int) get_option( 'baf_aps_2_0_2' ),
				],
			],

			[
				'callback' => [ $this->notice_cb, 'get_the_notice' ],
				'notice'   => [
					'noticeClass'    => 'error',
					'msg'            => '<span class="dashicons dashicons-lock bwl_plugins_notice_text--danger"></span> Please <a href="' . esc_url( get_admin_url() ) . 'admin.php?page=baf-license" class="bwl_plugins_notice_text--danger bwl_plugins_notice_text--bold">ACTIVATE YOUR COPY</a> of the plugin to unlock premium options and official support of ' . BAF_PLUGIN_TITLE . '.',
					'key'            => 'baf_license_activation_status',
					'status'         => ( BAF_PRODUCT_VERIFIED_STATUS === 1 ) ? 1 : 0,
					'is_dismissable' => 0,
				],
			],
		];

		$this->notices_api->add_notices( $notices )->register();
	}
}
