<?php

namespace BwlFaqManager\Controllers\ShortcodeEditor;

/**
 * Class Plugin shortcode editor.
 *
 * @package BwlFaqManager
 */
class PluginScEditor {

    /**
     * Register
     */
    public function register() {
        add_action( 'admin_init', [ $this, 'initialize' ] );
    }

    /**
     * Initialize actions and filters
     */
    public function initialize() {

        if ( ! current_user_can( 'edit_posts' ) && ! current_user_can( 'edit_pages' ) ) {
            return;
        }

        if ( get_user_option( 'rich_editing' ) !== 'true' ) {
            return;
        }

        // WPML FIXING IN VERSION 1.6.6
        $current_lang = 'en';

        if ( defined( 'ICL_SITEPRESS_VERSION' ) && isset( $_GET['lang'] ) ) {
            $current_lang = sanitize_text_field( $_GET['lang'] );
            set_transient( 'WPML_BAF_SELECTED_LANG', $current_lang );
        }

        add_filter( 'mce_external_plugins', [ $this,'add_shortcode_plugin' ] );
        add_filter( 'mce_buttons', [ $this,'register_shortcode_button' ] );
    }

    /**
     * Add Shortcode plugin.
     *
     * @param array $plugin_array plugin.
     * @return array
     */
    public function add_shortcode_plugin( $plugin_array ) {

        $plugin_array['baf'] = BAF_LIBS_DIR . 'tinymce/scripts/baf_tinymce_button.js';
        return $plugin_array;
    }

    /**
     * Register shortcode button.
     *
     * @param array $buttons button.
     * @return array
     */
    public function register_shortcode_button( $buttons ) {

        array_push( $buttons, 'baf' );
        return $buttons;
    }
}
