<?php
namespace BwlFaqManager\Helpers;

use BwlFaqManager\Helpers\PluginConstants;

/**
 * Class for FAQ helper functions
 *
 * @package BwlFaqManager
 */
class FaqHelper {

    /**
     * Get all the published FAQs.
     *
     * @param string $orderBy the order by.
     * @param string $order the order.
     * @return array
     */
    public static function get_all_published_faqs( $orderBy = 'title', $order = 'ASC' ) {
        $args = [
            'post_status'    => 'publish',
            'post_type'      => BAF_POST_TYPE,
            'orderby'        => $orderBy,
            'order'          => $order,
            'posts_per_page' => -1,
        ];

        return get_posts( $args );
    }

    /**
     * Change The Default WordPress Excerpt Length.
     *
     * @param int $status exceprt status.
     * @return string
     */
	public static function get_faq_excerpt( $status = 0 ) {

		$options = PluginConstants::$plugin_options;

		if ( $status === 1 ) {
			$options['bwl_advanced_faq_excerpt_status'] = 1;
		}

		if ( isset( $options['bwl_advanced_faq_excerpt_status'] ) && $options['bwl_advanced_faq_excerpt_status'] == 1 ) {

			$content = get_the_content();

			if ( str_word_count( $content ) > $options['bwl_advanced_faq_excerpt_length'] ) {

				$baf_excerpt_read_more = apply_filters( 'baf_excerpt_read_more_text', esc_html__( 'Read More', 'bwl-adv-faq' ) . ' &raquo;' );

				$trimmed_content = wp_trim_words( $content, $options['bwl_advanced_faq_excerpt_length'], '..... <a class="read-more" href="' . esc_url( get_permalink( get_the_ID() ) ) . '">' . $baf_excerpt_read_more . ' </a>' );
			} else {

				$trimmed_content = str_replace( ']]>', ']]&gt;', apply_filters( 'the_content', get_the_content() ) );
			}

			$content = $trimmed_content;
		} else {

			$content = str_replace( ']]>', ']]&gt;', apply_filters( 'the_content', get_the_content() ) );
		}

		$content = '<div class="baf_content">' . apply_filters( 'baf_force_content_shortcode', $content ) . '</div>';

		return $content;
	}
}
