<?php

namespace BwlFaqManager\Widgets;

use WP_Widget;
/**
 * Class for Display FAQs Topics Widget
 *
 * @package BwlFaqManager
 */
class FaqTopicsWidget extends WP_Widget {

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 */
    public function __construct() {
        parent::__construct(
            'baf_topics_widget',
            'Advanced FAQ Topics',
            [ 'description' => esc_html__( 'Display FAQ Topics', 'bwl-adv-faq' ) ]
        );
    }

    /**
	 * Create the widget form.
	 *
	 * @param array $instance widget instance.
	 * @return void
	 * @since 1.0.0
	 */
    public function form( $instance ) {

        $defaults = [
            'title'           => esc_html__( 'Topics', 'bwl-adv-faq' ),
            'entries_display' => 10,
            'show_post_count' => 'false',
        ];

        $instance = wp_parse_args( (array) $instance, $defaults );

		?>

<p>
    <label for="<?php $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'bwl-adv-faq' ); ?></label>
    <input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>"
    name="<?php echo $this->get_field_name( 'title' ); ?>" class="widefat"
    value="<?php echo esc_attr( $instance['title'] ); ?>" />
</p>

<p>
    <input type="checkbox" id="<?php echo $this->get_field_id( 'show_post_count' ); ?>"
    name="<?php echo $this->get_field_name( 'show_post_count' ); ?>"
		<?php checked( $instance['show_post_count'], 'on' ); ?> />&nbsp; Display Post Count?
</p>

		<?php

    }

    /**
	 * Update the widget data.
     *
     * @param array $new_instance new widget instance.
     * @param array $old_instance old widget instance.
     * @return $instance
     * @since 1.0.0
     */
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;

        // Widget Title
        $instance['title']           = sanitize_title( $new_instance['title'] );
        $instance['show_post_count'] = $new_instance['show_post_count'];

        return $instance;
    }

    /**
	 * Output the widget.
     *
     * @param array $args widget arguments.
     * @param array $instance widget instance.
     * @return void
     * @since 1.0.0
     */
    public function widget( $args, $instance ) {
        extract( $args );

        $title = apply_filters( 'widget-title', $instance['title'] );

        echo $before_widget;

        if ( $title ) :
            echo $before_title . esc_html( $title ) . $after_title;
        endif;

        $show_count = 0;

        $show_post_count = $instance['show_post_count'];

        if ( $show_post_count == 'on' ) {
            $show_count = 1;
        }

		?>

<ul class="baf-widget">

		<?php wp_list_categories( [ 'title_li' => '', 'taxonomy' => 'advanced_faq_topics', 'show_count' => $show_count, 'depth' => 2 ] ); ?>

</ul>

		<?php

        echo $after_widget;
    }
}
